@@ -7,6 +7,7 @@
 #'   Defaults to `"perc"`. The allowed types are `"perc"`, `"basic"`,
 #'   `"bca"`, and `"norm"`. Does not support `"stud"` or `"all"`.
 #' @template param_unused_dots
+#' @template param_exponentiate
 #'
 #' @evalRd return_tidy("bias", "std.error", "term",
 #'   statistic = "Original value of the statistic."
@@ -21,11 +22,7 @@
 #' and `statistic` columns are omitted, and only `estimate` and
 #' `std.error` columns shown.
 #'
-#' @examples
-#' 
-#' # feel free to ignore the following line—it allows {broom} to supply 
-#' # examples without requiring the model-supplying package to be installed.
-#' if (requireNamespace("boot", quietly = TRUE)) {
+#' @examplesIf rlang::is_installed("boot")
 #'
 #' # load modeling library
 #' library(boot)
@@ -44,13 +41,11 @@
 #' }
 #'
 #' bootres <- boot(clotting, bootfun, R = 999)
-#' 
+#'
 #' # summarize model fits with tidiers
 #' tidy(g1, conf.int = TRUE)
 #' tidy(bootres, conf.int = TRUE)
-#' 
-#' }
-#' 
+#'
 #' @export
 #' @aliases boot_tidiers
 #' @seealso [tidy()], [boot::boot()], [boot::tsboot()], [boot::boot.ci()],
@@ -59,6 +54,7 @@ tidy.boot <- function(x,
                       conf.int = FALSE,
                       conf.level = 0.95,
                       conf.method = c("perc", "bca", "basic", "norm"),
+                      exponentiate = FALSE,
                       ...) {
   conf.method <- rlang::arg_match(conf.method)
 
@@ -90,8 +86,7 @@ tidy.boot <- function(x,
       op <- cbind(t0, apply(t, 2L, mean, na.rm = TRUE) -
         t0, sqrt(apply(t, 2L, function(t.st) var(t.st[!is.na(t.st)]))))
       colnames(op) <- c("statistic", "bias", "std.error")
-    }
-    else {
+    } else {
       op <- NULL
       for (i in index) {
         op <- rbind(op, boot::imp.moments(boot.out,
@@ -129,5 +124,10 @@ tidy.boot <- function(x,
     colnames(ci.tab) <- c("conf.low", "conf.high")
     ret <- cbind(ret, ci.tab)
   }
+
+  if (exponentiate) {
+    ret <- exponentiate(ret, col = "statistic")
+  }
+
   as_tibble(ret)
 }
