@@ -54,6 +54,7 @@ tidy.anova <- function(x, ...) {
     "AIC" = "AIC", # merMod
     "BIC" = "BIC", # merMod
     "deviance" = "deviance", # merMod
+    "Deviance" = "deviance",
     "logLik" = "logLik", # merMod
     "Df" = "df",
     "Chi.Df" = "df",
@@ -61,6 +62,8 @@ tidy.anova <- function(x, ...) {
     "Mean Sq" = "meansq",
     "F value" = "statistic",
     "Pr(>F)" = "p.value",
+    "Resid..Dev" = "residual.deviance",
+    "Resid..Df" = "df.residual",
     "Res.Df" = "df.residual",
     "RSS" = "rss",
     "Sum of Sq" = "sumsq",
@@ -137,6 +140,7 @@ tidy.anova <- function(x, ...) {
       row.names(ret) <- NULL
     }
   } else if ((!"term" %in% colnames(ret)) & length(mod_lines) != 0) {
+    mod_lines <- gsub("\n    ", "", mod_lines)
     mods <- sub(".*: ", "", strsplit(mod_lines, "\n")[[1]])
     ret <- cbind(term = mods, ret)
   } else if ((!"term" %in% colnames(ret)) & !is.null(row.names(ret))) {
