@@ -28,9 +28,9 @@
 #'   geom_point() +
 #'   geom_vline(xintercept = 0, lty = 4) +
 #'   geom_errorbarh()
-#'   
-#' # aside: There are tidy() and glance() methods for lm.summary objects too. 
-#' # this can be useful when you want to conserve memory by converting large lm 
+#'
+#' # aside: There are tidy() and glance() methods for lm.summary objects too.
+#' # this can be useful when you want to conserve memory by converting large lm
 #' # objects into their leaner summary.lm equivalents.
 #' s <- summary(mod)
 #' tidy(s, conf.int = TRUE)
@@ -44,23 +44,23 @@
 #'   head(6) %>%
 #'   mutate(wt = wt + 1)
 #' augment(mod, newdata = newdata)
-#' 
+#'
 #' # ggplot2 example where we also construct 95% prediction interval
-#' 
+#'
 #' # simpler bivariate model since we're plotting in 2D
-#' mod2 <- lm(mpg ~ wt, data = mtcars) 
-#' 
+#' mod2 <- lm(mpg ~ wt, data = mtcars)
+#'
 #' au <- augment(mod2, newdata = newdata, interval = "prediction")
-#' 
-#' ggplot(au, aes(wt, mpg)) + 
+#'
+#' ggplot(au, aes(wt, mpg)) +
 #'   geom_point() +
-#'   geom_line(aes(y = .fitted)) + 
+#'   geom_line(aes(y = .fitted)) +
 #'   geom_ribbon(aes(ymin = .lower, ymax = .upper), col = NA, alpha = 0.3)
-#' 
+#'
 #' # predict on new data without outcome variable. Output does not include .resid
 #' newdata <- newdata %>%
 #'   select(-mpg)
-#'   
+#'
 #' augment(mod, newdata = newdata)
 #'
 #' au <- augment(mod, data = mtcars)
@@ -72,7 +72,7 @@
 #'   geom_smooth(se = FALSE)
 #'
 #' plot(mod, which = 6)
-#' 
+#'
 #' ggplot(au, aes(.hat, .cooksd)) +
 #'   geom_vline(xintercept = 0, colour = NA) +
 #'   geom_abline(slope = seq(0, 3, by = 0.5), colour = "white") +
@@ -83,14 +83,14 @@
 #' a <- matrix(rnorm(20), nrow = 10)
 #' b <- a + rnorm(length(a))
 #' result <- lm(b ~ a)
-#' 
+#'
 #' tidy(result)
-#' 
+#'
 #' @aliases lm_tidiers
 #' @export
 #' @seealso [tidy()], [stats::summary.lm()]
 #' @family lm tidiers
-tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95, 
+tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95,
                     exponentiate = FALSE, ...) {
   warn_on_subclass(x, "tidy")
 
@@ -111,7 +111,7 @@ tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95,
     ci <- broom_confint_terms(x, level = conf.level)
     ret <- dplyr::left_join(ret, ci, by = "term")
   }
-  
+
   if (exponentiate) {
     ret <- exponentiate(ret)
   }
@@ -134,7 +134,7 @@ tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95,
 #' @evalRd return_augment(
 #'   ".hat",
 #'   ".lower",
-#'   ".upper", 
+#'   ".upper",
 #'   ".sigma",
 #'   ".cooksd",
 #'   ".se.fit",
@@ -151,15 +151,15 @@ tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95,
 #' @seealso [augment()], [stats::predict.lm()]
 #' @family lm tidiers
 augment.lm <- function(x, data = model.frame(x), newdata = NULL,
-                       se_fit = FALSE, interval =  c("none", "confidence", "prediction"), ...) {
-  
+                       se_fit = FALSE, interval = c("none", "confidence", "prediction"), ...) {
   warn_on_subclass(x, "augment")
-  
+
   interval <- match.arg(interval)
   df <- augment_newdata(x, data, newdata, se_fit, interval)
 
   if (is.null(newdata)) {
-    tryCatch({
+    tryCatch(
+      {
         infl <- influence(x, do.coef = FALSE)
         df <- add_hat_sigma_cols(df, x, infl)
       },
@@ -182,9 +182,9 @@ augment.lm <- function(x, data = model.frame(x), newdata = NULL,
 #'   "sigma",
 #'   "statistic",
 #'   "p.value",
-#'   df = "The degrees for freedom from the numerator of the overall 
-#'     F-statistic. This is new in broom 0.7.0. Previously, this reported 
-#'     the rank of the design matrix, which is one more than the numerator 
+#'   df = "The degrees for freedom from the numerator of the overall
+#'     F-statistic. This is new in broom 0.7.0. Previously, this reported
+#'     the rank of the design matrix, which is one more than the numerator
 #'     degrees of freedom of the overall F-statistic.",
 #'   "logLik",
 #'   "AIC",
@@ -199,29 +199,38 @@ augment.lm <- function(x, data = model.frame(x), newdata = NULL,
 #' @seealso [glance()], [glance.summary.lm()]
 #' @family lm tidiers
 glance.lm <- function(x, ...) {
-  
   warn_on_subclass(x, "glance")
-  
+
   # check whether the model was fitted with only an intercept, in which
   # case drop the fstatistic related columns
   int_only <- nrow(summary(x)$coefficients) == 1
-  
+
   with(
     summary(x),
     tibble(
       r.squared = r.squared,
       adj.r.squared = adj.r.squared,
       sigma = sigma,
-      statistic = if (!int_only) {fstatistic["value"]} else {NA_real_},
+      statistic = if (!int_only) {
+        fstatistic["value"]
+      } else {
+        NA_real_
+      },
       p.value = if (!int_only) {
-        pf(
+        stats::pf(
           fstatistic["value"],
           fstatistic["numdf"],
           fstatistic["dendf"],
           lower.tail = FALSE
-          )
-        } else {NA_real_},
-      df = if (!int_only) {fstatistic["numdf"]} else {NA_real_},
+        )
+      } else {
+        NA_real_
+      },
+      df = if (!int_only) {
+        fstatistic["numdf"]
+      } else {
+        NA_real_
+      },
       logLik = as.numeric(stats::logLik(x)),
       AIC = stats::AIC(x),
       BIC = stats::BIC(x),
